@@ -44,7 +44,8 @@ class TheBlockchainAPIResource:
         """
         return {
             'APIKeyID': self.__api_key_id,
-            'APISecretKey': self.__api_secret_key
+            'APISecretKey': self.__api_secret_key,
+            'Language': 'Python'
         }
 
     def _request(self, payload, endpoint, request_method, files=None, headers=None):
